.. include:: ../../README.rst


.. toctree::
   :maxdepth: 1
   :hidden:

   overview
   installation
   api/index
   recipes/index
   visualization/index
   datasets
   references

	     

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
